package be.cylab.java.wowa.training;

import org.deeplearning4j.nn.api.OptimizationAlgorithm;
import org.nd4j.linalg.activations.Activation;

/**
 * Parameters of the NeuralNetwork class.
 */
public class HyperParameters {
    private int neurons_number;
    private double learning_rate;
    private OptimizationAlgorithm algorithm;
    private Activation activation_function;
    private double percent_test_train;

    /**
     * Default constructor.
     * @param neurons_number
     * @param learning_rate
     * @param algorithm
     * @param activation_function
     * @param percent_test_train
     */
    public HyperParameters(
            final int neurons_number,
            final double learning_rate,
            final OptimizationAlgorithm algorithm,
            final Activation activation_function,
            final double percent_test_train) {
        this.neurons_number = neurons_number;
        this.learning_rate = learning_rate;
        this.algorithm = algorithm;
        this.activation_function = activation_function;
        this.percent_test_train = percent_test_train;
    }

    /**
     * Constructor without percent_train_test value.
     * @param neurons_number
     * @param learning_rate
     * @param algorithm
     * @param activation_function
     */
    public HyperParameters(
            final int neurons_number,
            final double learning_rate,
            final OptimizationAlgorithm algorithm,
            final Activation activation_function) {
        this(neurons_number, learning_rate, algorithm,
                activation_function, (Double) null);
    }

    /**
     * Getter for neuron_number.
     * @return
     */
    public int getNeuronsNumber() {
        return neurons_number;
    }

    /**
     * Getter for learning rate.
     * @return
     */
    public double getLearningRate() {
        return learning_rate;
    }

    /**
     * Getter for backpropagation algorithm.
     * @return
     */
    public OptimizationAlgorithm getAlgorithm() {
        return algorithm;
    }

    /**
     * Getter for activation function.
     * @return
     */
    public Activation getActivationFunction() {
        return activation_function;
    }

    /**
     * Getter for percent_test_train.
     * @return
     */
    public double getPercentTestTrain() {
        return percent_test_train;
    }
}
