package be.cylab.java.wowa.training;

import org.deeplearning4j.nn.api.OptimizationAlgorithm;
import org.nd4j.linalg.activations.Activation;

/**
 * Class for learn in neuronal network.
 */
public final class MainDL4J {
    /**
     * Default constructor.
     */
    private MainDL4J() {

    }

    /**
     * Main class for neural-network learning.
     *
     * @param args
     */
    public static void main(final String[] args) {

        String file_name = args[0];
        double learning_rate = Double.parseDouble(args[1]);
        OptimizationAlgorithm optimization_algorithm;
        Activation activation_function;

        if (args[2].matches("CONJUGATE_GRADIENT")) {
            optimization_algorithm = OptimizationAlgorithm.CONJUGATE_GRADIENT;
        } else if (args[2].matches("LBFGS")) {
            optimization_algorithm = OptimizationAlgorithm.LBFGS;
        } else if (args[2].matches("LINE_GRADIENT_DESCENT")) {
            optimization_algorithm
                    = OptimizationAlgorithm.LINE_GRADIENT_DESCENT;
        } else if (args[2].matches("STOCHASTIC_GRADIENT_DESCENT")) {
            optimization_algorithm
                    = OptimizationAlgorithm.STOCHASTIC_GRADIENT_DESCENT;
        } else {
            throw new IllegalArgumentException(
                    "Not correct optimization algorithm");
        }

        if (args[3].matches("RELU")) {
            activation_function = Activation.RELU;
        } else if (args[3].matches("SIGMOID")) {
            activation_function = Activation.SIGMOID;
        } else if (args[3].matches("TANH")) {
            activation_function = Activation.TANH;
        } else {
            throw new IllegalArgumentException(
                    "Not correct activation function");
        }

        HyperParameters parameters = new HyperParameters(20, learning_rate,
                optimization_algorithm, activation_function);
        NeuralNetwork nn = new NeuralNetwork(parameters);
        nn.run("./ressources/webshell_data.json",
                "./ressources/webshell_expected.json");

        //NeuralNetwork nn = new NeuralNetwork(20, learning_rate,
        //        optimization_algorithm, activation_function);
        //nn.runCSV("webshell_data.csv");

    }
}
